"""
Copyright © 2021 Jeff Kletsky. All Rights Reserved.

License for this software, part of the pyDE1 package, is granted under
GNU General Public License v3.0 only
SPDX-License-Identifier: GPL-3.0-only
"""

class DE1:
    pass

class Scale:
    pass

class ScaleProcessor:
    pass

class FlowSequencer:
    pass

class DiscoveredDevices:
    pass